@@ -212,7 +212,8 @@ static void mount_autodir( char *path, pid_t pgrp,
 	{
 		close( pipefd[ 0 ] );
 		close( pipefd[ 1 ] );
-		msglog( MSG_FATAL|LOG_ERRNO, "mount_autodir: mount %s", path );
+		msglog( MSG_FATAL|LOG_ERRNO,
+				"incorrect autofs module loaded? mount %s", path );
 	}
   
 	autodir.mounted = 1;
