@@ -30,6 +30,11 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #define AUTODIR_VERSION		""
 #endif
 
+/*only versin 4 is supported*/
+#define AUTODIR_PROTO_MIN 4
+#define AUTODIR_PROTO_MAX 4
+#define AUTODIR_PROTO_DEFAULT 4
+
 char *autodir_name( void );
 void autodir_option_path( char ch, char *arg, int valid );
 void autodir_option_modpath( char ch, char *arg, int valid );
