@@ -421,7 +421,7 @@ void backup_child_stop_set( void )
 	stop = 1;
 }
 
-static int backup_signal_all( void )
+static void backup_signal_all( void )
 {
 	int i;
 	Backup_pid *bp, **dptr;
