@@ -26,6 +26,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
+#include <time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "msg.h"
@@ -270,3 +271,43 @@ void string_safe( char *str, int rep )
 		str++;
 	}
 }
+
+int rename_dir( const char *from, const char *to_dir, const char *to_name,
+							const char *tme_format )
+{
+	char to[ PATH_MAX+1 ];
+	time_t now;
+	struct tm tmval;
+	char str_time[ 256 ];
+	int try;
+
+	now = time( NULL );
+	for( try = 0; try < 10; try++ )
+	{
+		if( localtime_r(&now, &tmval) == NULL )
+		{
+			msglog( MSG_ERR,
+				"localtime_r: could not convert current time" );
+			return -1;
+		}
+		if( ! strftime(str_time, sizeof(str_time), tme_format, &tmval ) )
+		{
+			msglog( MSG_ERR, "strftime: could not make the time") ;
+			return -1;
+		}
+		snprintf(to, sizeof(to), "%s/%s%s", to_dir, to_name, str_time );
+		if( rename( from, to ) )
+		{
+			if ( errno == ENOTEMPTY || errno == EEXIST )
+			{
+				now++;
+				continue;
+			}
+			msglog( MSG_WARNING|LOG_ERRNO,
+					"could not rename %s to %s", from, to );
+			return -1;
+		}
+		return 0;
+	}
+	return -1;
+}
