@@ -44,5 +44,7 @@ int octal_string2dec( const char *str, unsigned int *oct );
 int write_all( int fd, const char *buf, int buf_sz );
 unsigned int string_hash( const char *str );
 void string_safe( char *str, int rep );
+int rename_dir( const char *from, const char *to_dir, const char *to_name,
+						    const char *tme_format );
 
 #endif
