@@ -70,7 +70,10 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 /*do everything quite fast!*/
 #define SUB_OPTION_FASTMODE		"fastmode"
 
+/*Rename dir to copy all those group dirs with gid mismatch/stale*/
+#define SUB_OPTION_RENAMEDIR		"renamedir"
 
+/********************************************************/
 
 /*default module option values*/
 #define DFLT_AUTOGROUP_REALPATH		"/" MODULE_NAME
@@ -102,6 +105,7 @@ module_info autogroup_info = { MODULE_NAME, MODULE_PROTOCOL };
 /*module option values*/
 static struct {
 	char realpath[ PATH_MAX+1 ];
+	char renamedir[ PATH_MAX+1 ];
 	int level;
 	int nopriv;
 	int nocheck;
@@ -220,6 +224,7 @@ static void option_process( char *subopt )
 		OPTION_OWNER_IDX,
 		OPTION_GROUP_IDX,
 		OPTION_FASTMODE_IDX,
+		OPTION_RENAMEDIR_IDX,
 		END
 	};
 
@@ -232,6 +237,7 @@ static void option_process( char *subopt )
 		[ OPTION_OWNER_IDX    ]	= SUB_OPTION_OWNER,
 		[ OPTION_GROUP_IDX    ]	= SUB_OPTION_GROUP,
 		[ OPTION_FASTMODE_IDX ] = SUB_OPTION_FASTMODE,
+		[ OPTION_RENAMEDIR_IDX ] = SUB_OPTION_RENAMEDIR,
 		[ END                 ] = NULL
 	};
 
@@ -277,8 +283,16 @@ static void option_process( char *subopt )
 				ag_conf.fastmode = 1;
 				break;
 
+			case OPTION_RENAMEDIR_IDX:
+				string_n_copy( ag_conf.renamedir, 
+					path_option_check( value,
+						sos[ OPTION_RENAMEDIR_IDX ] ),
+					sizeof( ag_conf.renamedir) );
+				break;
+
 			default:
-				msglog( MSG_FATAL, "unknown module suboption %s", value );
+				msglog( MSG_FATAL,
+					"unknown module suboption %s", value );
 		}
 	}
 }
@@ -286,11 +300,13 @@ static void option_process( char *subopt )
 static void autogroup_conf_init( char *opts )
 {
 	ag_conf.realpath[ 0 ] = 0;
+	ag_conf.renamedir[ 0 ] = 0;
 	ag_conf.nopriv = -1;
 	ag_conf.level = -1;
 	ag_conf.mode = -1;
 	ag_conf.nocheck = 0;
 	ag_conf.owner = 0;
+	ag_conf.group = -1;
 	ag_conf.fastmode = 0;
 
 	option_process( opts );
@@ -324,7 +340,11 @@ static void autogroup_conf_init( char *opts )
 	}
 }
 
-static int create_group_dir( const char *groupdir, uid_t uid, gid_t gid )
+
+#define TME_FORMAT "-%Y_%d%b_%H:%M:%S." MODULE_NAME
+
+static int create_group_dir( const char *name, const char *groupdir,
+							uid_t uid, gid_t gid )
 {
 	struct stat st;
 
@@ -346,6 +366,19 @@ static int create_group_dir( const char *groupdir, uid_t uid, gid_t gid )
 			return 1;
 		if( st.st_gid != gid )
 		{
+			if( *ag_conf.renamedir )
+			{
+				msglog( MSG_ALERT,
+					"group dir %s is not owned by its user. " \
+					"moving to %s", groupdir,
+					ag_conf.renamedir );
+				if( rename_dir( groupdir, ag_conf.renamedir,
+							    name, TME_FORMAT) )
+					return 0;
+				else
+					goto groupdir_create;
+				return 0;
+			}
 			msglog( MSG_ALERT, "group directory %s is not owned by its group. " \
 				"fixing", groupdir );
 
@@ -374,7 +407,8 @@ static int create_group_dir( const char *groupdir, uid_t uid, gid_t gid )
 	}
 	else if( errno == ENOENT )
 	{
-		msglog( MSG_INFO, "group directory %s does not exist. creating", groupdir );
+groupdir_create:
+		msglog( MSG_INFO, "creating group directory %s", groupdir );
 
 		if( ! create_dir( groupdir, 0700 ) )
 			return 0;
@@ -409,24 +443,26 @@ module_info *module_init( char *subopt, const char *groupbase )
 
 	if( ! create_dir( ag_conf.realpath, 0700 ) )
 	{
-		msglog( MSG_ALERT, "module_init: " \
-			"could not create autogroup dir %s",
-			ag_conf.realpath );
+		msglog( MSG_ALERT, "could not create group dir %s",
+							ag_conf.realpath );
+		return NULL;
+	}
+	if( *ag_conf.renamedir && ! create_dir( ag_conf.renamedir, 0700 ) )
+	{
+		msglog( MSG_ALERT, "could not create renamedir %s",
+							ag_conf.renamedir );
 		return NULL;
 	}
-
 	if( ! strcmp( groupbase, ag_conf.realpath ) )
 	{
 		msglog( MSG_ALERT, "group dir and autofs dir are same" );
 		return NULL;
 	}
-
 	if( ( pwd_bufsz = sysconf( _SC_GETPW_R_SIZE_MAX ) ) == -1 )
 	{
 		msglog( MSG_ALERT|LOG_ERRNO, "sysconf _SC_GETPW_R_SIZE_MAX" );
 		return NULL;
 	}
-
 	if( ( grp_bufsz = sysconf( _SC_GETGR_R_SIZE_MAX ) ) == -1 )
 	{
 		msglog( MSG_ALERT|LOG_ERRNO, "sysconf _SC_GETGR_R_SIZE_MAX" );
@@ -512,7 +548,7 @@ static int get_group_info( const char *name, gid_t *gid )
 
 /* create real group dir and check permissions.*/
 int module_dowork(const char *name,
-		const char *dummy,
+		const char *unused,
 		char *realdir, int rlen)
 {
 	int upriv;
@@ -540,10 +576,72 @@ int module_dowork(const char *name,
 		}
 		if( upriv == -1 ) return 0;
 	}
-	return create_group_dir( realdir, ag_conf.owner, gid );
+	return create_group_dir( name, realdir, ag_conf.owner, gid );
 }
 
 void module_clean( void )
 {
 	/*nothing to be done*/
 }
+
+
+
+
+
+
+
+
+
+
+#ifdef TEST
+
+#include <assert.h>
+
+char *autodir_name(void)
+{
+    return "test autodir";
+}
+
+void *test_th(void *x)
+{
+    char realdir[PATH_MAX+1];
+    char name[128];
+    int i;
+
+    while (1) {
+	for (i = 10000; i < 19000; i++) {
+	    snprintf(name, sizeof(name), "t%d", i);
+	    workon_name(name);
+	    assert(module_dowork(name, NULL, realdir, sizeof(realdir)));
+	    workon_release(name);
+	}
+	printf("i=%d\n", i);
+    }
+}
+
+int main(void)
+{
+    pthread_t id;
+
+    thread_init();
+    msg_init();
+    msg_console_on();
+    workon_init();
+    module_init(strdup("renamedir=/tmp/renamedir"), "/test");
+
+    //test_th(NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+
+    pthread_join(id, NULL);
+}
+
+#endif
