@@ -76,9 +76,12 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 /*owner for every home directory*/
 #define SUB_OPTION_OWNER		"owner"
 
-/*Try to be fast*/
+/*Try to be fast. skipping everything else*/
 #define SUB_OPTION_FASTMODE		"fastmode"
 
+/*Rename dir to copy all those home dirs with uid mismatch/stale homes*/
+#define SUB_OPTION_RENAMEDIR		"renamedir"
+
 /************************************************************/
 
 
@@ -122,6 +125,7 @@ int getsubopt (char **, const char* const *, char **);
 static struct {
 	char realpath[ PATH_MAX+1 ]; /*real base directory*/
 	char skel[ PATH_MAX+1 ]; 
+	char renamedir[ PATH_MAX+1 ];
 	int noskel; 
 	int level; 
 	int nocheck; 
@@ -251,6 +255,7 @@ static void option_process( char *subopt )
 		OPTION_GROUP_IDX,
 		OPTION_FASTMODE_IDX,
  		OPTION_NOHOMECHECK_IDX,
+		OPTION_RENAMEDIR_IDX,
 		END
 	};
 
@@ -266,6 +271,7 @@ static void option_process( char *subopt )
 		[ OPTION_GROUP_IDX    ]	= SUB_OPTION_GROUP,
 		[ OPTION_FASTMODE_IDX ] = SUB_OPTION_FASTMODE,
  		[ OPTION_NOHOMECHECK_IDX ] = SUB_OPTION_NOHOMECHECK,
+		[ OPTION_RENAMEDIR_IDX ] = SUB_OPTION_RENAMEDIR,
 		[ END                 ] = NULL
 	};
 
@@ -326,9 +332,16 @@ static void option_process( char *subopt )
  				ah_conf.nohomecheck = 1;
  				break;
 
+			case OPTION_RENAMEDIR_IDX:
+				string_n_copy( ah_conf.renamedir, 
+					path_option_check( value,
+						sos[ OPTION_RENAMEDIR_IDX ] ),
+					sizeof( ah_conf.renamedir) );
+				break;
+
 			default:
-				msglog( MSG_FATAL, "unknown module suboption '%s'",
-								value );
+				msglog( MSG_FATAL,
+				    "unknown module suboption '%s'", value );
 		}
 	}
 }
@@ -337,6 +350,7 @@ static void autohome_conf_init( char *opts )
 {
 	ah_conf.realpath[ 0 ] = 0;
 	ah_conf.skel[ 0 ] = 0;
+	ah_conf.renamedir[ 0 ] = 0;
 	ah_conf.noskel = 0;
 	ah_conf.level = -1;
 	ah_conf.mode = -1;
@@ -694,10 +708,14 @@ static int copy_skel( const char *src, /*skel directory*/
 	return 0;
 }
 
-static int create_home_dir( const char *home, /*real path for home directory*/
-				const char *skel, /*system skel source directory*/
-				uid_t uid,
-				gid_t gid )
+
+#define TME_FORMAT "-%Y_%d%b_%H:%M:%S." MODULE_NAME
+
+static int create_home_dir( const char *name,
+			const char *home, /*real path for home directory*/
+			const char *skel, /*system skel source directory*/
+			uid_t uid,
+			gid_t gid )
 {
 	char stamp[ PATH_MAX+1 ];
 	struct stat home_st, stamp_st;
@@ -717,22 +735,22 @@ static int create_home_dir( const char *home, /*real path for home directory*/
 				"but it is not directory", home );
 			return 0;
 		}
-		if( ! ah_conf.noskel )
-		{
-			snprintf( stamp, sizeof(stamp), "%s/%s",
-					home, AUTOHOME_STAMP_FILE );
-			if( lstat( stamp, &stamp_st ) && errno == ENOENT )
-			{
-				msglog( MSG_NOTICE, "create_home_dir: " \
-					"skel stamp file %s does not exist. " \
-					"copying skel dir", stamp );
-				copy_skel( skel, home, uid, gid );
-			}
-		}
 		if( ah_conf.nocheck )
 			return 1;
 		if( home_st.st_uid != uid )
 		{
+			if( *ah_conf.renamedir )
+			{
+				msglog( MSG_ALERT,
+					"home %s is not owned by its user. " \
+					"moving to %s", home, ah_conf.renamedir );
+				if( rename_dir( home, ah_conf.renamedir,
+							    name, TME_FORMAT) )
+					return 0;
+				else
+					goto home_create;
+				return 0;
+			}
 			msglog( MSG_ALERT, "home %s is not owned by its user. " \
 				"fixing", home );
 
@@ -764,10 +782,23 @@ static int create_home_dir( const char *home, /*real path for home directory*/
 					"chmod %s", home );
 			}
 		}
+		if( ! ah_conf.noskel )
+		{
+			snprintf( stamp, sizeof(stamp), "%s/%s",
+					home, AUTOHOME_STAMP_FILE );
+			if( lstat( stamp, &stamp_st ) && errno == ENOENT )
+			{
+				msglog( MSG_NOTICE, "create_home_dir: " \
+					"skel stamp file %s does not exist. " \
+					"copying skel dir", stamp );
+				copy_skel( skel, home, uid, gid );
+			}
+		}
 	}
 	else if( errno == ENOENT )
 	{
-		msglog( MSG_INFO, "home %s does not exist. creating", home );
+home_create:
+		msglog( MSG_INFO, "creating home %s", home );
 
 		if( ! create_dir( home, S_IRUSR | S_IWUSR | S_IXUSR ) )
 			return 0;
@@ -787,7 +818,7 @@ static int create_home_dir( const char *home, /*real path for home directory*/
 	}
 	else
 	{
-		msglog( MSG_ERR, "create_home_dir: lstat %s", home );
+		msglog( MSG_ERR|LOG_ERRNO, "create_home_dir: lstat %s", home );
 		return 0;
 	}
 	return 1;
@@ -799,12 +830,16 @@ module_info *module_init( char *subopt, const char *homebase )
 
 	if( ! create_dir( ah_conf.realpath, 0700 ) )
 	{
-		msglog( MSG_ALERT, "module_init: " \
-			"could not create auto home real path %s",
-			ah_conf.realpath );
+		msglog( MSG_ALERT, "could not create home real path %s",
+							ah_conf.realpath );
+		return NULL;
+	}
+	if( *ah_conf.renamedir && ! create_dir( ah_conf.renamedir, 0700 ) )
+	{
+		msglog( MSG_ALERT, "could not create renamedir %s",
+							ah_conf.renamedir );
 		return NULL;
 	}
-
 	if( ! strcmp( homebase, ah_conf.realpath ) )
 	{
 		msglog( MSG_ALERT, "home base '%s' and real path '%s' are same",
@@ -911,10 +946,72 @@ int module_dowork( const char *name,
 		}
 	}
 
-	return create_home_dir( realhome, ah_conf.skel, uid, gid );
+	return create_home_dir( name, realhome, ah_conf.skel, uid, gid );
 }
 
 void module_clean( void )
 {
 	/*nothing to be done*/
 }
+
+
+
+
+
+
+
+
+
+
+#ifdef TEST
+
+#include <assert.h>
+
+char *autodir_name(void)
+{
+    return "test autodir";
+}
+
+void *test_th(void *x)
+{
+    char realdir[PATH_MAX+1];
+    char name[128];
+    int i;
+
+    while (1) {
+	for (i = 10000; i < 19000; i++) {
+	    snprintf(name, sizeof(name), "t%d", i);
+	    workon_name(name);
+	    assert(module_dowork(name, "/test", realdir, sizeof(realdir)));
+	    workon_release(name);
+	}
+	printf("i=%d\n", i);
+    }
+}
+
+int main(void)
+{
+    pthread_t id;
+
+    thread_init();
+    msg_init();
+    msg_console_on();
+    workon_init();
+    module_init(strdup("renamedir=/tmp/renamedir"), "/test");
+
+    //test_th(NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+    pthread_create(&id, 0, test_th, NULL);
+
+    pthread_join(id, NULL);
+}
+
+#endif
