@@ -32,6 +32,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <errno.h>
 #include <sys/types.h>
 #include "msg.h"
+#include "time_mono.h"
 #include "thread.h"
 
 /*If it is 32bit machine you might want to optimize this value.
@@ -96,6 +97,8 @@ static void condattr_init(void)
 {
         const char        *myname = "condattr_init";
 
+	time_mono_init();
+
         if ( ( errno = pthread_condattr_init( &common_cond_attr ) ) )
                 msglog(MSG_FATAL|LOG_ERRNO, "%s: pthread_condattr_init",
                         myname);
@@ -105,21 +108,11 @@ static void condattr_init(void)
                 msglog( MSG_FATAL|LOG_ERRNO, "%s: pthread_condattr_setpshared: " \
                         "PTHREAD_PROCESS_PRIVATE", myname);
 
-#if defined _POSIX_CLOCK_SELECTION && _POSIX_CLOCK_SELECTION >= 0
-#if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0) 
-#if defined(_POSIX_MONOTONIC_CLOCK) && (_POSIX_MONOTONIC_CLOCK >= 0)
-        if ( ( errno = pthread_condattr_setclock(&common_cond_attr,
-                                                CLOCK_MONOTONIC ) ) )
+#if defined _POSIX_CLOCK_SELECTION && _POSIX_CLOCK_SELECTION >= 0 \
+			&& defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
+        if ( ( errno = pthread_condattr_setclock(&common_cond_attr, clockid ) ) )
                 msglog( MSG_FATAL|LOG_ERRNO, "%s: pthread_condattr_setclock",
                                                 myname );
-#else
-#warning "CLOCK_MONOTONIC not available. using CLOCK_REALTIME"
-        if ( ( errno = pthread_condattr_setclock( &common_cond_attr,
-                                                CLOCK_REALTIME ) ) )
-                msglog( MSG_FATAL|LOG_ERRNO, "%s: pthread_condattr_setclock",
-                                                myname );
-#endif
-#endif
 #endif
 }
 
