@@ -30,24 +30,33 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include "time_mono.h"
 
+#if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
+clockid_t clockid = CLOCK_REALTIME;
+#endif
+
+static int initialized = 0;
+
+#ifdef TEST
+#if 0
+#ifdef _POSIX_MONOTONIC_CLOCK
+#undef _POSIX_MONOTONIC_CLOCK
+#endif
+#ifdef _POSIX_TIMERS
+#undef _POSIX_TIMERS
+#endif
+#endif
+#endif
+
 time_t time_mono( void )
 {
 	const char *myname = "time_monotonic";
-#if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
-	struct timespec tp;
-#endif
 
 #if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
-#if defined(_POSIX_MONOTONIC_CLOCK) && (_POSIX_MONOTONIC_CLOCK >= 0)
-	if( clock_gettime( CLOCK_MONOTONIC, &tp ) )
+	struct timespec tp;
+
+	if( clock_gettime( clockid, &tp ) )
 		msglog( MSG_FATAL|LOG_ERRNO, 
 				    "%s: clock_gettime failed", myname );
-#else
-#warning "CLOCK_MONOTONIC not available. using CLOCK_REALTIME"
-	if( clock_gettime( CLOCK_REALTIME, &tp ) )
-		msglog( MSG_FATAL|LOG_ERRNO, 
-				    "%s: clock_gettime failed", myname );
-#endif
 	return tp.tv_sec;
 #else
 #warning "time_mono using time() interface"
@@ -58,19 +67,13 @@ time_t time_mono( void )
 /*For use with pthread_cond_timedwait*/
 struct timespec *thread_cond_timespec( struct timespec *tp, time_t sec )
 {
-#if defined _POSIX_CLOCK_SELECTION && _POSIX_CLOCK_SELECTION >= 0
-#if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
-#if defined(_POSIX_MONOTONIC_CLOCK) && (_POSIX_MONOTONIC_CLOCK >= 0)
-	if ( clock_gettime( CLOCK_MONOTONIC, tp ) )
+#if defined _POSIX_CLOCK_SELECTION && _POSIX_CLOCK_SELECTION >= 0 \
+			&& defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
+	if ( clock_gettime( clockid, tp ) )
 		msglog( MSG_FATAL|LOG_ERRNO, "thread_cond_timespec: " \
 						    "clock_gettime failed" );
 #else
-	if ( clock_gettime( CLOCK_REALTIME, tp ) )
-		msglog( MSG_FATAL|LOG_ERRNO, "thread_cond_timespec: " \
-						    "clock_gettime failed" );
-#endif
-#endif
-#else
+#warning "not using _POSIX_CLOCK_SELECTION"
 	tp->tv_sec = time( NULL );
 	tp->tv_nsec = 0;
 #endif
@@ -83,7 +86,7 @@ struct timespec *mono_timespec( struct timespec *tp, time_t sec, long nsec )
 {
 #if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
 #if defined(_POSIX_MONOTONIC_CLOCK) && (_POSIX_MONOTONIC_CLOCK >= 0)
-	if ( clock_gettime( CLOCK_MONOTONIC, tp ) )
+	if ( clock_gettime( clockid, tp ) )
 		msglog( MSG_FATAL|LOG_ERRNO, 
 				    "mono_timespec: clock_gettime failed" );
 #else
@@ -105,33 +108,97 @@ void mono_nanosleep( long nsec )
 {
 	struct timespec tp;
 
-#if defined(_POSIX_CLOCK_SELECTION) && (_POSIX_CLOCK_SELECTION > 0)
-#if defined(_POSIX_MONOTONIC_CLOCK) && (_POSIX_MONOTONIC_CLOCK >= 0)
+#if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0)
 	tp.tv_sec = 0;
 	tp.tv_nsec = nsec;
-	if( clock_nanosleep( CLOCK_MONOTONIC, 0, &tp, NULL ) )
+	if( clock_nanosleep( clockid, 0, &tp, NULL ) )
 		msglog( MSG_ERR|LOG_ERRNO, 
-			    "mono_nanosleep: clock_nanosleep CLOCK_MONOTONIC" );
+			    "mono_nanosleep: clock_nanosleep" );
 	return;
 #else
 	tp.tv_sec = 0;
 	tp.tv_nsec = nsec;
-	if( clock_nanosleep( CLOCK_REALTIME, 0, &tp, NULL ) )
-		msglog( MSG_ERR|LOG_ERRNO, 
-			    "mono_nanosleep: clock_nanosleep CLOCK_REALTIME" );
-	return;
-#endif
-#else
-	tp.tv_sec = time( NULL );
-	tp.tv_nsec = nsec;
 	if( nanosleep( &tp, NULL ) )
 		msglog( MSG_ERR|LOG_ERRNO, "mono_nanosleep: nanosleep" );
 #endif
-	return;
 }
 
 void time_mono_init(void)
 {
-    /*call for the first time to see any fatal errors*/
-    time_mono();
+	if( initialized )
+		return;
+#if defined(_POSIX_TIMERS) && (_POSIX_TIMERS > 0) && \
+	defined(_POSIX_MONOTONIC_CLOCK) && (_POSIX_MONOTONIC_CLOCK >= 0)
+
+	if( sysconf( _SC_MONOTONIC_CLOCK ) > 0 )
+		clockid = CLOCK_MONOTONIC;
+#else
+#warning "CLOCK_MONOTONIC not available. using CLOCK_REALTIME"
+#endif
+
+	/*call for the first time to see any fatal errors*/
+	time_mono();
+	initialized = 1;
 }
+
+#ifdef TEST
+
+#include "thread.h"
+
+char *autodir_name(void)
+{
+    return "test autodir";
+}
+
+int main(void)
+{
+	int i;
+	pthread_mutex_t lock;
+	pthread_cond_t cond;
+	struct timespec tspec;
+
+	thread_init();
+	time_mono_init();
+	
+	printf("time_mono %ld\n", (long) time_mono());
+	sleep(1);
+	printf("time_mono %ld\n", (long) time_mono());
+	sleep(1);
+	printf("time_mono %ld\n", (long) time_mono());
+	sleep(1);
+	printf("time_mono %ld\n", (long) time_mono());
+	sleep(1);
+	printf("time_mono %ld\n", (long) time_mono());
+	sleep(1);
+	printf("time_mono %ld\n", (long) time_mono());
+	sleep(1);
+	printf("time_mono %ld\n", (long) time_mono());
+	sleep(1);
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+	printf("time_mono %ld\n", (long) time_mono());
+
+	thread_mutex_init(&lock);
+	thread_cond_init(&cond);
+	thread_cond_timespec(&tspec, 10);
+	pthread_mutex_lock(&lock);
+	printf("pthread_cond_timedwait next %ld\n", time_mono());
+	pthread_cond_timedwait(&cond, &lock, &tspec);
+	printf("pthread_cond_timedwait end %ld\n", time_mono());
+
+	printf("mono_nanosleep next %ld\n", time_mono());
+	for( i = 0 ; i < 1000; i++) {
+		mono_nanosleep(100000000);
+	}
+	printf("mono_nanosleep end %ld\n", time_mono());
+}
+
+#endif
