@@ -399,6 +399,32 @@ int main(void)
     pthread_create(&id, 0, test_th, "x");
     pthread_create(&id, 0, test_th, "y");
     pthread_create(&id, 0, test_th, "z");
+    pthread_create(&id, 0, test_th, "A");
+    pthread_create(&id, 0, test_th, "B");
+    pthread_create(&id, 0, test_th, "C");
+    pthread_create(&id, 0, test_th, "D");
+    pthread_create(&id, 0, test_th, "E");
+    pthread_create(&id, 0, test_th, "F");
+    pthread_create(&id, 0, test_th, "G");
+    pthread_create(&id, 0, test_th, "H");
+    pthread_create(&id, 0, test_th, "I");
+    pthread_create(&id, 0, test_th, "J");
+    pthread_create(&id, 0, test_th, "K");
+    pthread_create(&id, 0, test_th, "L");
+    pthread_create(&id, 0, test_th, "M");
+    pthread_create(&id, 0, test_th, "N");
+    pthread_create(&id, 0, test_th, "O");
+    pthread_create(&id, 0, test_th, "P");
+    pthread_create(&id, 0, test_th, "Q");
+    pthread_create(&id, 0, test_th, "R");
+    pthread_create(&id, 0, test_th, "S");
+    pthread_create(&id, 0, test_th, "T");
+    pthread_create(&id, 0, test_th, "U");
+    pthread_create(&id, 0, test_th, "V");
+    pthread_create(&id, 0, test_th, "W");
+    pthread_create(&id, 0, test_th, "X");
+    pthread_create(&id, 0, test_th, "Y");
+    pthread_create(&id, 0, test_th, "Z");
 
     pthread_create(&id, 0, test_th, "1");
     pthread_create(&id, 0, test_th, "2");
@@ -435,6 +461,32 @@ int main(void)
     pthread_create(&id, 0, test_th, "x");
     pthread_create(&id, 0, test_th, "y");
     pthread_create(&id, 0, test_th, "z");
+    pthread_create(&id, 0, test_th, "A");
+    pthread_create(&id, 0, test_th, "B");
+    pthread_create(&id, 0, test_th, "C");
+    pthread_create(&id, 0, test_th, "D");
+    pthread_create(&id, 0, test_th, "E");
+    pthread_create(&id, 0, test_th, "F");
+    pthread_create(&id, 0, test_th, "G");
+    pthread_create(&id, 0, test_th, "H");
+    pthread_create(&id, 0, test_th, "I");
+    pthread_create(&id, 0, test_th, "J");
+    pthread_create(&id, 0, test_th, "K");
+    pthread_create(&id, 0, test_th, "L");
+    pthread_create(&id, 0, test_th, "M");
+    pthread_create(&id, 0, test_th, "N");
+    pthread_create(&id, 0, test_th, "O");
+    pthread_create(&id, 0, test_th, "P");
+    pthread_create(&id, 0, test_th, "Q");
+    pthread_create(&id, 0, test_th, "R");
+    pthread_create(&id, 0, test_th, "S");
+    pthread_create(&id, 0, test_th, "T");
+    pthread_create(&id, 0, test_th, "U");
+    pthread_create(&id, 0, test_th, "V");
+    pthread_create(&id, 0, test_th, "W");
+    pthread_create(&id, 0, test_th, "X");
+    pthread_create(&id, 0, test_th, "Y");
+    pthread_create(&id, 0, test_th, "Z");
 
     pthread_create(&id, 0, test_th, "1");
     pthread_create(&id, 0, test_th, "2");
@@ -471,6 +523,32 @@ int main(void)
     pthread_create(&id, 0, test_th, "x");
     pthread_create(&id, 0, test_th, "y");
     pthread_create(&id, 0, test_th, "z");
+    pthread_create(&id, 0, test_th, "A");
+    pthread_create(&id, 0, test_th, "B");
+    pthread_create(&id, 0, test_th, "C");
+    pthread_create(&id, 0, test_th, "D");
+    pthread_create(&id, 0, test_th, "E");
+    pthread_create(&id, 0, test_th, "F");
+    pthread_create(&id, 0, test_th, "G");
+    pthread_create(&id, 0, test_th, "H");
+    pthread_create(&id, 0, test_th, "I");
+    pthread_create(&id, 0, test_th, "J");
+    pthread_create(&id, 0, test_th, "K");
+    pthread_create(&id, 0, test_th, "L");
+    pthread_create(&id, 0, test_th, "M");
+    pthread_create(&id, 0, test_th, "N");
+    pthread_create(&id, 0, test_th, "O");
+    pthread_create(&id, 0, test_th, "P");
+    pthread_create(&id, 0, test_th, "Q");
+    pthread_create(&id, 0, test_th, "R");
+    pthread_create(&id, 0, test_th, "S");
+    pthread_create(&id, 0, test_th, "T");
+    pthread_create(&id, 0, test_th, "U");
+    pthread_create(&id, 0, test_th, "V");
+    pthread_create(&id, 0, test_th, "W");
+    pthread_create(&id, 0, test_th, "X");
+    pthread_create(&id, 0, test_th, "Y");
+    pthread_create(&id, 0, test_th, "Z");
 
     pthread_create(&id, 0, test_th, "1");
     pthread_create(&id, 0, test_th, "2");
@@ -507,6 +585,32 @@ int main(void)
     pthread_create(&id, 0, test_th, "x");
     pthread_create(&id, 0, test_th, "y");
     pthread_create(&id, 0, test_th, "z");
+    pthread_create(&id, 0, test_th, "A");
+    pthread_create(&id, 0, test_th, "B");
+    pthread_create(&id, 0, test_th, "C");
+    pthread_create(&id, 0, test_th, "D");
+    pthread_create(&id, 0, test_th, "E");
+    pthread_create(&id, 0, test_th, "F");
+    pthread_create(&id, 0, test_th, "G");
+    pthread_create(&id, 0, test_th, "H");
+    pthread_create(&id, 0, test_th, "I");
+    pthread_create(&id, 0, test_th, "J");
+    pthread_create(&id, 0, test_th, "K");
+    pthread_create(&id, 0, test_th, "L");
+    pthread_create(&id, 0, test_th, "M");
+    pthread_create(&id, 0, test_th, "N");
+    pthread_create(&id, 0, test_th, "O");
+    pthread_create(&id, 0, test_th, "P");
+    pthread_create(&id, 0, test_th, "Q");
+    pthread_create(&id, 0, test_th, "R");
+    pthread_create(&id, 0, test_th, "S");
+    pthread_create(&id, 0, test_th, "T");
+    pthread_create(&id, 0, test_th, "U");
+    pthread_create(&id, 0, test_th, "V");
+    pthread_create(&id, 0, test_th, "W");
+    pthread_create(&id, 0, test_th, "X");
+    pthread_create(&id, 0, test_th, "Y");
+    pthread_create(&id, 0, test_th, "Z");
 
     pthread_join(id, NULL);
 }
